# Create an index to be used my static_gen
from zipfile import ZipFile
from pictures._util import check_valid_archive, check_jpg
from os.path import dirname
from structures import Index, Section, Image


def make_index(archive_path: str,
               search_captions: bool = False) -> Index:
    if not check_valid_archive(archive_path):
        raise ValueError("Cannot make index from an invalid archive")

    with ZipFile(archive_path, 'r') as zip:
        names = zip.namelist()
    section_names = {dirname(x) for x in names}
    sections = [Section(x, [Image(y)
                            for y in names
                            if dirname(y) == x and check_jpg(y)])
                for x in section_names]
    sections = [x for x in sections if len(x.images) > 0]

    if search_captions:
        raise NotImplementedError
    else:
        return Index(sections)
