import argparse


def add_render_parser(top_level_parsers: argparse._SubParsersAction):
    parser: argparse.ArgumentParser = top_level_parsers.add_parser("render")

    parser.add_argument("-a", "--archive",
                        help="path to archive",
                        dest="archive_path",
                        nargs=1,
                        required=True)
    parser.add_argument("-o", "--output",
                        help="path to dump html",
                        dest="output",
                        required=False,
                        default=None)

    parser.set_defaults(func=run_render)


def run_render(args):
    from pictures.make_index import make_index
    from static_gen.render import gen_page

    output = gen_page(make_index(archive_path=args.archive_path[0]))
    if args.output is not None:
        try:
            with open(args.output, 'x') as file:
                file.write(output)
        except FileExistsError:
            print(f"Refusing to clobber output: {args.output} already exists.")
    else:
        print(output)
